Page 23 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 23

Home

    may have been a warning that public exposure could
    follow, thus galvanizing their determination to destroy

    Jesus.

    However the case, there did exist at the time of
    Christ, an assemblage of doctrines and speculations that
    were carefully concealed from the multitude. For the
    most part these doctrines (contained in the Jewish
    Cabala) were directed against orthodox Judaism. The
    word "cabala" comes from a Hebrew word that signifies
    "a doctrine orally received." Although the date is
    uncertain, these doctrines were eventually written in

    Cabala. On the other hand, the Koran, the holy book of
    the Muslims, denounces the infamous legends

    the

    the Muslims, denounces the infamou
    concerning Christ perpetuated by the Jews.

    18

    The Secret Side of History

    In the minds of the Pharisees such a condemnation

    what is now known as the Zohar.

    After the establishment of Christianity, slanders on

    Christ and Christians occurred in some versions of the

    denounces